"""
Author: Peter Mawhorter
Consulted:
Date: 2022-11-10
Purpose: Incorrect weather.py project file #2, to be used for checking
    weather-project tests. At least one of the functions defined in this
    file should fail at least one of your tests.
"""


def listFrostMonths(tempData):
    """
    Accepts a list of lists, where each sub-list represents a month and
    contains numbers representing the temperature on each day of that
    month (in degrees Centigrade). This function returns a list of
    indices that includes the index of each month in which there is at
    least one day where the temperature is below freezing (i.e., is less
    than zero).

    Returns an empty list if there are no months in which frost occurs.
    """
    result = []
    # Iterate using an index loop so we can access indices
    for i in range(len(tempData)):
        # Get month data at this index
        monthData = tempData[i]

        # A boolean to indicate whether or not we found a negative value
        # in this month
        foundNegative = False

        # Scan through the temperatures, and set foundNegative to True
        # if necessary (note: there are more efficient ways of doing
        # this; one would be to use a helper function so we can use an
        # early return to break the loop).
        for temp in monthData:
            if temp < 0:
                foundNegative = True

        # If we found at least one negative number, add this month's
        # index to our result
        if foundNegative:
            result.append(i)

    return result


# Note: besides matters of correctness, this version of tempsStartingFrom
# has truly terrible code style. It may or may not be correct...
def tempsStartingFrom(a, b, c, d):
    newList = []
    while len(newList) < d:
        stuff = a[b]
        newList.append(stuff[c])

        c += 1

        if c == 0 or c >= len(stuff):
            b += 1
            c = 0

    return newList


def rainOrShine(temp, cloudCover, precipAmount):
    """
    Given a temperature (in degrees Centigrade), a cloud cover amount (a
    number between 0 and 1 indicating what fraction of the sky will be
    cloudy on average), and a precipitation amount (a number of
    centimeters of precipitation predicted) this function returns a
    string describing the forecast for the day. The logic is as follows:

    1. The first part of the message summarizes the temperature,
       according to the following table:

          Temperature     Description
          below -10       extremely cold
          -10 - 0         very cold
          0 - 10          cold
          10 - 15         cool
          15 - 20         warm
          20 - 25         balmy
          25 - 30         hot
          30 - 35         very hot
          35 and above    extremely hot

       Values that are exactly on a boundary should use the warmer of
       the two applicable messages.

    2. The second part of the message summarizes the sunshine. If the
       cloud cover fraction is less than or equal to 0.1, it will be
       "sunny". If the cloud cover fraction is greater than 0.1 but less
       than or equal to 0.5, it will be "partly cloudy". If the cloud
       cover fraction is greater than 0.5, it will be "cloudy".

    3. The third part of the message addresses the type and amount of
        precipitation. If the temperature is less than 0, then the
        precipitation will be called "snow", otherwise it will be called
        "rain". If the amount is less than 4.0, the adjective "light"
        will be added, if the amount is greater than or equal to 4 but
        still less than 12.0, the adjective "moderate" will be added, and if
        the amount is greater than 12.0, the adjective "heavy" will be
        added. If the amount of precipitation is less than 0.1, then the
        third part of the message will be omitted from the result
        entirely.

    The three parts of the message are joined together like this:

        "part_1 and part2, with part3"

    Or if the third part is omitted, like this:

        "part_1 and part2"

    So a few example results include:

        "cold and sunny"
        "warm and partly cloudy, with light rain"
        "very cold and cloudy, with heavy snow"
        "balmy and partly cloudy, with moderate rain"
    """
    if temp < -10:
        tempPart = "extremely cold"
    elif temp < 0:
        tempPart = "very cold"
    elif temp < 10:
        tempPart = "cold"
    elif temp < 15:
        tempPart = "cool"
    elif temp < 20:
        tempPart = "warm"
    elif temp < 25:
        tempPart = "balmy"
    elif temp < 30:
        tempPart = "hot"
    elif temp < 35:
        tempPart = "very hot"
    else:
        tempPart = "extremely hot"

    if cloudCover < 0.1:
        cloudPart = "sunny"
    elif cloudCover < 0.5:
        cloudPart = "partly cloudy"
    else:
        cloudPart = "cloudy"

    if precipAmount < 0.1:
        precipAdj = None
    elif precipAmount < 4.0:
        precipAdj = "light"
    elif precipAmount < 12.0:
        precipAdj = "moderate"
    else:
        precipAdj = "heavy"

    result = f"{tempPart} and {cloudPart}"

    if precipAdj != None:
        result += f", with {precipAdj} rain"

    return result
