"""
Author: Peter Mawhorter
Consulted:
Date: 2022-11-10
Purpose: Incorrect weather.py project file #3, to be used for checking
    weather-project tests. At least one of the functions defined in this
    file should fail at least one of your tests.
"""


def listFrostMonths(tempData):
    """
    Accepts a list of lists, where each sub-list represents a month and
    contains numbers representing the temperature on each day of that
    month (in degrees Centigrade). This function returns a list of
    indices that includes the index of each month in which there is at
    least one day where the temperature is below freezing (i.e., is less
    than zero).

    Returns an empty list if there are no months in which frost occurs.
    """
    result = []
    # Iterate using an index loop so we can access indices
    for i in range(len(tempData)):
        # Get month data at this index
        monthData = tempData[i]

        # A boolean to indicate whether or not we found a negative value
        # in this month
        foundNegative = False

        # Scan through the temperatures, and set foundNegative to True
        # if necessary (note: there are more efficient ways of doing
        # this; one would be to use a helper function so we can use an
        # early return to break the loop).
        for temp in monthData:
            if temp < 0:
                foundNegative = True

        # If we found at least one negative number, add this month's
        # index to our result
        if foundNegative:
            result.append(i)

    return result


def tempsStartingFrom(tempData, monthIndex, dayIndex, daysToList):
    """
    This function returns a list of temperature values for the
    temperature starting on a specific day of a specific month and
    continuing for a specific number of days. The parameters specify the
    temperature data, the month to start at, the day to start at, and the
    number of days to include.

    The temperature data will be a list of lists, where each sub-list
    represents a month and contains one temperature number for each day.

    If asked for data which is not available (e.g., starting on the last
    available day and continuing for 2 days, or starting from a day
    that's after the end of the specified month) this function will
    raise an IndexError.

    Negative month and day indices count backwards from the end of the
    month or day lists, per Python's default indexing behavior.
    """
    result = []
    # Keep going until we have enough days listed
    while len(result) < daysToList:
        # First, append this temperature value to our result
        month = tempData[monthIndex]
        result.append(month[dayIndex])

        # Next, increment the day index
        dayIndex += 1

        # If that causes the dayIndex to be 0 or invalid, increment the
        # monthIndex and set the dayIndex back to 0.
        if dayIndex > len(month):
            monthIndex += 1
            dayIndex = 0

    return result


def rainOrShine(temp, cloudCover, precipAmount):
    """
    Given a temperature (in degrees Centigrade), a cloud cover amount (a
    number between 0 and 1 indicating what fraction of the sky will be
    cloudy on average), and a precipitation amount (a number of
    centimeters of precipitation predicted) this function returns a
    string describing the forecast for the day. The logic is as follows:

    1. The first part of the message summarizes the temperature,
       according to the following table:

          Temperature     Description
          below -10       extremely cold
          -10 - 0         very cold
          0 - 10          cold
          10 - 15         cool
          15 - 20         warm
          20 - 25         balmy
          25 - 30         hot
          30 - 35         very hot
          35 and above    extremely hot

       Values that are exactly on a boundary should use the warmer of
       the two applicable messages.

    2. The second part of the message summarizes the sunshine. If the
       cloud cover fraction is less than or equal to 0.1, it will be
       "sunny". If the cloud cover fraction is greater than 0.1 but less
       than or equal to 0.5, it will be "partly cloudy". If the cloud
       cover fraction is greater than 0.5, it will be "cloudy".

    3. The third part of the message addresses the type and amount of
        precipitation. If the temperature is less than 0, then the
        precipitation will be called "snow", otherwise it will be called
        "rain". If the amount is less than 4.0, the adjective "light"
        will be added, if the amount is greater than or equal to 4 but
        still less than 12.0, the adjective "moderate" will be added, and if
        the amount is greater than 12.0, the adjective "heavy" will be
        added. If the amount of precipitation is less than 0.1, then the
        third part of the message will be omitted from the result
        entirely.

    The three parts of the message are joined together like this:

        "part_1 and part2, with part3"

    Or if the third part is omitted, like this:

        "part_1 and part2"

    So a few example results include:

        "cold and sunny"
        "warm and partly cloudy, with light rain"
        "very cold and cloudy, with heavy snow"
        "balmy and partly cloudy, with moderate rain"
    """
    if temp >= 35:
        tempPart = "extremely hot"
    elif temp >= 30:
        tempPart = "very hot"
    elif temp >= 25:
        tempPart = "hot"
    elif temp >= 20:
        tempPart = "balmy"
    elif temp >= 15:
        tempPart = "warm"
    elif temp >= 10:
        tempPart = "cool"
    elif temp >= 0:
        tempPart = "cold"
    elif temp >= -10:
        tempPart = "very cold"
    else:
        tempPart = "extremely cold"

    if cloudCover <= 0.1:
        cloudPart = "sunny"
    elif cloudCover <= 0.5:
        cloudPart = "partly cloudy"
    else:
        cloudPart = "cloudy"

    if temp < 0:
        precipType = "snow"
    else:
        precipType = "rain"

    if precipAmount < 0.1:
        precipAdj = None
    elif precipAmount < 4.0:
        precipAdj = "light"
    elif precipAmount < 12.0:
        precipAdj = "moderate"
    else:
        precipAdj = "heavy"

    result = f"{tempPart} and {cloudPart}"

    if precipAdj != None:
        result += f", with {precipAdj} {precipType}"

    return result
